# asciiMOL

[![PyPI version](https://badge.fury.io/py/asciimol.svg)](https://badge.fury.io/py/asciimol)

![Screenshots](docs/anim.gif)

A basic molecule viewer written in Python, using curses; Thus, meant for linux terminals.

This is an alpha version, featuring:

* Opening default cartesian .xyz files
* Displaying one-letter atom labels
* Orthographic view
* Zoom, Rotation
* Simple Colors for common light atoms
* Basic bond detection and display

On the horizon:
* Perspective / Orthographic view toggle
* More formats
* Custom Colors

## Installation

```sh
pip install asciimol
```
